@@ -1,4 +1,5 @@
 import hashlib
+import importlib
 import itertools
 import os
 import re
@@ -16,6 +17,7 @@ from pydantic import BaseModel, validator, Field, root_validator
 
 from typhoon.core.cron_utils import aws_schedule_to_cron
 from typhoon.core.settings import Settings
+from typhoon.introspection.introspect_extensions import get_typhoon_extensions_info
 
 IDENTIFIER_REGEX = r'\w+'
 Identifier = Field(..., regex=r'\w+')
@@ -45,6 +47,10 @@ class Py:
     def construct(loader: yaml.Loader, node: yaml.Node):
         return construct_custom_class(Py, loader, node)
 
+    @staticmethod
+    def represent(dumper: yaml.Dumper, data: 'Py'):
+        return dumper.represent_scalar('!Py', data.value)
+
     @classmethod
     def __get_validators__(cls):
         yield cls.validate
@@ -103,6 +109,10 @@ class MultiStep:
     def construct(loader: yaml.Loader, node: yaml.Node):
         return construct_custom_class(MultiStep, loader, node)
 
+    @staticmethod
+    def represent(dumper: yaml.Dumper, data: 'MultiStep'):
+        return dumper.represent_sequence('MultiStep', data.value)
+
     @classmethod
     def __get_validators__(cls):
         yield cls.validate
@@ -251,6 +261,16 @@ class TestCase(BaseModel):
             result['pd'] = pd
         except ImportError:
             print('Warning: could not import pandas. Run pip install pandas if you want to use dataframes')
+        result['SimpleNamespace'] = SimpleNamespace
+
+        # Import functions
+        from typhoon.core.transpiler.transpiler_helpers import extract_imports, typhoon_import_transformation_as
+
+        extensions_info = get_typhoon_extensions_info()
+        for k, v in extensions_info['transformations'].items():
+            import_from = importlib.import_module(v)
+            import_as = typhoon_import_transformation_as(k)
+            result[import_as] = import_from
         return result
 
     @property
@@ -306,6 +326,16 @@ def add_yaml_constructors():
     yaml.add_constructor('!Template', construct_template)
 
 
+def represent_granularity(dumper: yaml.Dumper, data: Granularity):
+    return dumper.represent_str(data.value)
+
+
+def add_yaml_representers(dumper: yaml.Dumper):
+    yaml.add_representer(Py, Py.represent, dumper)
+    yaml.add_representer(MultiStep, MultiStep.represent, dumper)
+    yaml.add_representer(Granularity, represent_granularity, dumper)
+
+
 def get_deps_uses_batch_and_warnings(item):
     deps = []
     warnings = []
@@ -375,6 +405,11 @@ class TaskDefinition(BaseModel):
                 raise ValueError(f'Arg "{k}" should be an identifier')
             if isinstance(v, MultiStep):
                 v.key = k
+            # HACK: We don't have custom JSON decoders so we need to create Py and MultiStep objects here if applicable
+            if isinstance(v, dict) and v.get('__typhoon__') == 'Py':
+                val[k] = Py(v['value'])
+            elif isinstance(v, dict) and v.get('__typhoon__') == 'MultiStep':
+                val[k] = MultiStep(v['value'])
         return val
 
     @validator('function')
@@ -465,6 +500,15 @@ class TaskDefinition(BaseModel):
         custom_locals['batch_num'] = batch_num
         custom_locals['dag_context'] = dag_context
 
+        # Import functions
+        from typhoon.core.transpiler.transpiler_helpers import extract_imports, typhoon_import_transformation_as
+
+        extensions_info = get_typhoon_extensions_info()
+        for k, v in extensions_info['transformations'].items():
+            import_from = importlib.import_module(v)
+            import_as = typhoon_import_transformation_as(k)
+            custom_locals[import_as] = import_from
+
         os.environ['TYPHOON_ENV'] = 'dev'
 
         results = {}
@@ -560,8 +604,10 @@ class DAGDefinitionV2(BaseModel):
               r'((\*|\?|\d+((\/|\-){0,1}(\d+))*)\s*){5,6}' + '|' +
               r'rate\(\s*1\s+minute\s*\)' + '|' +
               r'rate\(\s*\d+\s+minutes\s*\)' + '|' +
-              r'rate\(\s1*\d+\s+hour\s*\)' + '|' +
+              r'rate\(\s*1\s+hour\s*\)' + '|' +
               r'rate\(\s*\d+\s+hours\s*\)' + '|' +
+              r'rate\(\s*1\s+day\s*\)' + '|' +
+              r'rate\(\s*\d+\s+days\s*\)' +
               ')',
         description='Schedule or frequency on which the DAG should run'
     )
@@ -645,6 +691,12 @@ class DAGDefinitionV2(BaseModel):
             del self.tasks[task_name]
         self.tasks.update(**tasks_to_add)
 
+    class Config:
+        json_encoders = {
+            Py: lambda v: {'__typhoon__': 'Py', 'value': v.value},
+            MultiStep: lambda v: {'__typhoon__': 'MultiStep', 'value': v.value},
+        }
+
 
 def uses_batch(item):
     if isinstance(item, Py):
@@ -661,34 +713,10 @@ def uses_batch(item):
 
 
 if __name__ == '__main__':
-    add_yaml_constructors()
-    dag_v2 = """
-name: example_v2
-schedule_interval: "@hourly"
-
-tasks:
-    tables:
-        function: typhoon.flow_control.branch
-        args:
-            branches:
-                - sheep
-                - dog
-    
-    extract:
-        input: tables
-        function: typhoon.relational.query
-        asynchronous: False
-        args:
-            sql: !Py f'select * from {$BATCH}'
-            hook: !Py $HOOKS.oracle_db
-            batch_size: 500
-    
-    load:
-        input: extract
-        function: typhoon.filesystem.write_data
-        args:
-            hook: !Py $HOOKS.data_lake
-            data: !Py typhoon.transformations.write_csv($BATCH.data)
-            path: !Py f'{$BATCH.table_name}/part{$BATCH_NUM}.csv'
-    """
-    print(yaml.dump(DAGDefinitionV2.parse_obj(yaml.load(dag_v2, yaml.FullLoader)).make_dag().dict(), Dumper=yaml.Dumper, sort_keys=False))
+    add_yaml_representers(yaml.SafeDumper)
+    print(yaml.safe_dump({
+        'a': 'abc',
+        'b': [1, 2, 3],
+        'c': Py('abcd'),
+        'd': MultiStep([1, 'a', 2]),
+    }))
