@@ -1,11 +1,15 @@
+import importlib
 import inspect
 import pkgutil
+import re
 from importlib import import_module
+from inspect import Parameter
 from pathlib import Path
 from pkgutil import ModuleInfo
 from types import ModuleType
-from typing import List, Tuple, Dict, Type
+from typing import List, Tuple, Dict, Type, Mapping, Optional
 
+import dataclasses
 from typing_extensions import TypedDict
 
 from typhoon.contrib.hooks.hook_interface import HookInterface
@@ -61,6 +65,7 @@ def get_typhoon_extensions_info(extensions: ExtensionsList = None) -> Extensions
             info[ext_folder][function_module_name] = str(sub_module_path.relative_to(typhoon_contrib_path.parent.parent)) \
                 .replace('.py', '').replace('/', '.')
     for component_path in (typhoon_contrib_path / 'components').rglob('*.yml'):
+        # TODO: Fix if component name isn't the same as the filename
         component_name = component_path.stem
         info['components'][component_name] = str(component_path)
     return info
@@ -77,3 +82,37 @@ def get_hooks_info(extensions_info: ExtensionsInfo = None) -> Dict[str, Type[Hoo
             if conn_type:
                 hooks_info[conn_type] = cls
     return hooks_info
+
+
+@dataclasses.dataclass
+class FunctionInfo:
+    module: str
+    name: str
+    args: Mapping[str, Parameter]
+    docstring: Optional[str]
+    _arg_docs: dict = None
+
+    def __post_init__(self):
+        self._arg_docs = {}
+        if self.docstring:
+            for k, v in re.findall(r':param (\w+):\s*(.*)', self.docstring):
+                self._arg_docs[k] = v
+
+    @property
+    def arg_docs(self) -> dict:
+        return self._arg_docs or {}
+
+
+
+def functions_info_in_module_path(module_name: str, module_path: str) -> List[FunctionInfo]:
+    functions_module = importlib.import_module(module_path)
+    functions_info = []
+    for function_name, function in inspect.getmembers(functions_module, inspect.isfunction):
+        signature = inspect.signature(function)
+        functions_info.append(FunctionInfo(
+            module=f'typhoon.{module_name}',
+            name=function_name,
+            args=signature.parameters,
+            docstring=function.__doc__,
+        ))
+    return functions_info
